mutation createEnterpriseOrg($organization: CreateEnterpriseOrganizationInput!){
	createEnterpriseOrganization(input:$organization)
	{
		enterprise{
			id
			name
		}
		organization{
            id
			login
			name
			url
		}
		
	}		
}