query getRepoCollaborators($owner: String!, $name: String!, $cursor: String) {
  repository(owner: $owner, name: $name) {
    nameWithOwner
    url
    visibility
    collaborators(first: 100, after: $cursor) {
      totalCount
      edges {
        permission
        node {
          login
        }
      }
      pageInfo {
        hasNextPage
        endCursor
      }
    }
  }
}
