query getOrgRepos($organization: String!, $cursor: String) {
  organization(login: $organization) {
    repositories(first: 100, after: $cursor) {
      totalCount
      edges {
        node {
          name
          nameWithOwner
          url
          visibility
        }
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
